@@ -22,10 +22,24 @@ getTypeTmpl = '''static PyObject *_wrap_%s(PyObject *self, PyObject *args) {
     return PyInt_FromLong(%s());
 }\n\n'''
 
+convSpecialCases = {
+	'GtkCList': '_GTK_CLIST',
+	'GtkCTree': '_GTK_CTREE',
+	'GtkCTreePos': '_GTK_CTREE_POS',
+	'GtkCTreeLineStyle': '_GTK_CTREE_LINE_STYLE',
+	'GtkCTreeExpanderStyle': '_GTK_CTREE_EXPANDER_STYLE',
+	'GtkCTreeExpansionStyle': '_GTK_CTREE_EXPANSION_STYLE',
+	'GnomeRootWin': '_GNOME_ROOTWIN',
+	'GnomeAppBar': '_GNOME_APPBAR',
+	'GnomeDEntryEdit': '_GNOME_DENTRY_EDIT',
+}
+
 def toUpperStr(str):
 	"""Converts a typename to the equivalent upercase and underscores
 	name.  This is used to form the type conversion macros and enum/flag
 	name variables"""
+	if convSpecialCases.has_key(str):
+		return convSpecialCases[str]
 	ret = []
 	while str:
 		if len(str) > 1 and str[0] in string.uppercase and \
@@ -58,19 +72,9 @@ def enumName(typename):
 	else:
 		return 'GTK_TYPE' + part
 
-convSpecialCases = {
-	'GtkCList': 'GTK_CLIST',
-	'GtkCTree': 'GTK_CTREE',
-	'GnomeRootWin': 'GNOME_ROOTWIN',
-	'GnomeAppBar': 'GNOME_APPBAR',
-	'GnomeDEntryEdit': 'GNOME_DENTRY_EDIT',
-}
 def conversionMacro(typename):
 	"""get the conversion macro for the given type"""
-	if convSpecialCases.has_key(typename):
-		return convSpecialCases[typename]
-	else:
-		return toUpperStr(typename)[1:]
+	return toUpperStr(typename)[1:]
 
 # a dictionary of known enum types ...
 # the value is a cached copy of the GTK_TYPE name
@@ -103,7 +107,10 @@ boxed = {
 			     'PyGtkSelectionData_Get',
 			     'PyGtkSelectionData_New'),
 	'GdkAtom': ('PyGdkAtom_Type', 'PyGdkAtom_Get', 'PyGdkAtom_New'),
-	'GdkCursor': ('PyGdkCursor_Type', 'PyGdkCursor_Get', 'PyGdkCursor_New'),
+	'GdkCursor': ('PyGdkCursor_Type', 'PyGdkCursor_Get',
+		      'PyGdkCursor_New'),
+	'GtkCTreeNode': ('PyGtkCTreeNode_Type', 'PyGtkCTreeNode_Get',
+			 'PyGtkCTreeNode_New'),
 }
 
 class VarDefs:
